@@ -1,6 +1,6 @@
 /**
  * perl-libxml-sax.c
- * $Id: perl-libxml-sax.c,v 1.26 2003/08/22 22:16:16 phish Exp $
+ * $Id: perl-libxml-sax.c,v 1.27 2004/02/14 18:35:13 pajas Exp $
  */
 
 #ifdef __cplusplus
@@ -367,7 +367,9 @@ PmmGenElementSV( pTHX_ PmmSAXVectorPtr sax, const xmlChar * name )
                  _C2Sv(name, NULL), NameHash);
 
         localname = xmlSplitQName(NULL, name, &prefix);
+        if (localname != NULL) xmlFree(localname);
         ns = PmmGetNsMapping( sax->ns_stack, prefix );
+        if (prefix != NULL) xmlFree(prefix);
 
         if ( ns != NULL ) {
             hv_store(retval, "NamespaceURI", 12,
